=====================================================================
 Python Promises
=====================================================================

:Version: 1.0.0rc1
:Web: http://vine.readthedocs.org/
:Download: http://pypi.python.org/pypi/vine/
:Source: http://github.com/celery/vine/
:Keywords: promise, async, future

About
=====

.. image:: https://d2weczhvl823v0.cloudfront.net/celery/vine.png
    :alt: Bitdeli badge
    :target: https://bitdeli.com/free
